==> tecfy_corev2_package-1.0.1.tar.gz: lib/services/account.service.dart <==
part of tecfy_corev2_client_package;

class AccountService {
  static Future<bool> init(BuildContext? context,
      {bool withRedirection = true}) async {
    try {
      await ConfigService.init();
      // await ConfigService.loadConfig();
      if (ConfigService.getValueBool('LoginExpired')) {
        //ConfigService.isLogin = false;
        if (context != null)
          AppNavigator.navigateToNamed(context, '/login',
              replaceAll: true, animationType: AnimationTypes.opacity);
      }
      if (ConfigService.isLogin) {
        await InitService.afterLoginInit();
        initFull(context);
        if (withRedirection && context != null) {
          if (kDebugMode) print('ConfigService.isLogin');
          await TecfyCoreApp.navigateToDefaultPage(context);
        }
        return true;
      } else {
        var isLoginResult = await initFull(context);
        if (isLoginResult) {
          InitService.afterLoginInit();
          if (withRedirection && context != null) {
            if (kDebugMode) print('else ConfigService.isLogin');
            await TecfyCoreApp.navigateToDefaultPage(context);
          }
          return true;
        } else if (kDebugMode) print("initFull retuens false");
      }
      //return true;
    } catch (err) {
      print(
          'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx init account error xxxxxxxxxxxxxxxx');
      print(err);
      // return false;
    }
    if (kDebugMode)
      print('XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX Go to login');
    if (context != null)
      AppNavigator.navigateToNamed(context, '/login',
          replaceAll: true, animationType: AnimationTypes.opacity);
    return true;
  }

  Future<OperationResult> login(String username, String password) async {
    try {
      print(ConfigService.apiURL);
      var result = await TecfyBasicApp.apiService.httpPostEx('admin/auth/login',
          {'username': username, 'password': password}, false);
      if (!result.success) {
        print(
            'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  login result XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX');
        print(result);
        print(result.message);
        print(result.errorCodeString);
        print(result.data);
        return result;
      }
      if (kDebugMode) print('================= LOGIN ================');
      if (kDebugMode) print(result.data);
      if (kDebugMode) print(result.data['token']);
      if (result.data['company'] == null ||
          result.data['user']['companyId'] == null ||
          result.data['user']['companyId'].length == 0) {
        result.data['user']['isSuperuser'] = true;
      }
      await ConfigService.setValueBool('LoginExpired', false);
      ConfigService.setValueMap(
          ConfigKeys.user, User.fromJson(result.data['user']).toJson());
      ConfigService.token = result.data['token'];
      if (result.data['company'] != null)
        ConfigService.setValueMap(ConfigKeys.company, result.data['company']);

      ConfigService.isLogin = true;
      return OperationResult(success: result.success, message: result.message);
    } catch (err, t) {
      print(
          'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  error ar login!! XXXXXXXXXXXXXXXXXXXX');
      print(err);
      return OperationResult(
          success: false, message: err.toString(), innerError: t.toString());
    }
  }

  static Future<bool> initFull(context) async {
    try {
      //ConfigService.loadConfig();
    } catch (err) {}
    return ConfigService.token.isNotEmpty;
    // var u = await FirebaseAuth.instance.currentUser();
    // if (u == null) {
    //   return false;
    // } else {
    //   // load user info from firestore
    //   isAnonymous = u.isAnonymous;
    //   await loadUser(u.uid);
    //   return true;
    // }
  }

  static Future signout(context, [bool forceSignout = false]) async {
    try {
      if (!forceSignout) {
        var result = await AppNavigator.confirmMessage(
            context, AppLocale.translate('Are you sure you want to logout?'));
        if (!result) return;
        try {
          int pending = await TecfySyncService.getUnpostedCount();
          if (pending > 0) {
            result = await AppNavigator.confirmMessage(context,
                'You have $pending local items not posted to server!!!!',
                message:
                    AppLocale.translate('Are you sure you want to logout?'));
            if (!result) return;
          }
        } catch (e) {}
      }

      try {
        DashboardController.dashboards = null;
        await ConfigService.resetConfig();
        await ConfigService.setValueString('Entity', null);
        await ConfigService.setValueString('DashboardAllType', null);
        await ConfigService.resetConfig();
      } catch (err) {}
      await DatabaseService.deleteDatabaseFile();
      await TecfySyncService.reset();
      await DatabaseService.init();
      AppNavigator.navigateToNamed(context, '/login',
          replaceAll: true, animationType: AnimationTypes.opacity);
    } catch (err, stack) {
      print('XXXXXXXXXXXX Logout ');
      print(err);
      print(stack);
      AppNavigator.showMessage(context, 'Error', MessageType.error);
    }
  }

  static lock(context) async {
    try {
      await ConfigService.setValueBool('LoginExpired', true);
      AppNavigator.navigateToNamed(context, '/login',
          replaceAll: true, animationType: AnimationTypes.opacity);
    } catch (err, stack) {
      print('XXXXXXXXXXXX Logout ');
      print(err);
      print(stack);
      AppNavigator.showMessage(context, 'Error', MessageType.error);
    }
  }

  static loginExpired(context) async {
    try {
      await ConfigService.setValueBool('LoginExpired', true);
      AppNavigator.navigateToNamed(context, '/login',
          replaceAll: true, animationType: AnimationTypes.opacity);
    } catch (err, stack) {
      print('XXXXXXXXXXXX Logout ');
      print(err);
      print(stack);
      AppNavigator.showMessage(context, 'Error', MessageType.error);
    }
  }

  static Future<OperationResult> loadUser(String id) async {
    try {
      // var userDataMap =
      //     await Firestore.instance.collection('users').document(id).get();

      // user = User.fromJson(id, userDataMap.data);
      //ConfigService.saveConfig();

      // await prefs.commit();
      return OperationResult(success: true);
    } catch (err) {
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<bool>> isLogin(context) async {
    if (ConfigService.isLogin)
      return OperationResult(success: true, data: true);
    await Future.delayed(Duration(milliseconds: 100));

    return OperationResult(success: true, data: false);
  }
}

==> tecfy_corev2_package-1.1.30.tar.gz: lib/services/account.service.dart <==
part of tecfy_corev2_client_package;

class AccountService {
  static Future<bool> init(BuildContext? context,
      {bool withRedirection = true}) async {
    try {
      await ConfigService.init();
      // await ConfigService.loadConfig();
      if (ConfigService.getValueBool('LoginExpired')) {
        //ConfigService.isLogin = false;
        if (context != null)
          AppNavigator.navigateToNamed(context, '/login',
              replaceAll: true, animationType: AnimationTypes.opacity);
      }
      if (ConfigService.isLogin) {
        await InitService.afterLoginInit();
        initFull(context);
        if (withRedirection && context != null) {
          if (kDebugMode) print('ConfigService.isLogin');
          await TecfyCoreApp.navigateToDefaultPage(context);
        }
        return true;
      } else {
        var isLoginResult = await initFull(context);
        if (isLoginResult) {
          InitService.afterLoginInit();
          if (withRedirection && context != null) {
            if (kDebugMode) print('else ConfigService.isLogin');
            await TecfyCoreApp.navigateToDefaultPage(context);
          }
          return true;
        } else if (kDebugMode) print("initFull retuens false");
      }
      //return true;
    } catch (err) {
      print(
          'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx init account error xxxxxxxxxxxxxxxx');
      print(err);
      // return false;
    }
    if (kDebugMode)
      print('XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX Go to login');
    if (context != null)
      AppNavigator.navigateToNamed(context, '/login',
          replaceAll: true, animationType: AnimationTypes.opacity);
    return true;
  }

  Future<OperationResult> login(String username, String password) async {
    try {
      print(ConfigService.apiURL);
      var result = await TecfyBasicApp.apiService.httpPostEx(
          'admin/auth/login', {'email': username, 'password': password}, false);
      if (!result.success) {
        print(
            'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  login result XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX');
        print(result);
        print(result.message);
        print(result.errorCodeString);
        print(result.data);
        return result;
      }
      if (kDebugMode) print('================= LOGIN ================');
      if (kDebugMode) print(result.data);
      if (kDebugMode) print(result.data['token']);
      // if (result.data['company'] == null ||
      //     result.data['user']['companyId'] == null ||
      //     result.data['user']['companyId'].length == 0) {
      //   result.data['user']['isSuperuser'] = true;
      // }
      await ConfigService.setValueBool('LoginExpired', false);
      ConfigService.setValueMap(
          ConfigKeys.user, User.fromJson(result.data['admin']).toJson());
      ConfigService.token = result.data['token'];
      if (result.data['company'] != null)
        ConfigService.setValueMap(ConfigKeys.company, result.data['company']);

      ConfigService.isLogin = true;
      return OperationResult(success: result.success, message: result.message);
    } catch (err, t) {
      print(
          'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  error ar login!! XXXXXXXXXXXXXXXXXXXX');
      print(err);
      return OperationResult(
          success: false, message: err.toString(), innerError: t.toString());
    }
  }

  static Future<bool> initFull(context) async {
    try {
      //ConfigService.loadConfig();
    } catch (err) {}
    return ConfigService.token.isNotEmpty;
    // var u = await FirebaseAuth.instance.currentUser();
    // if (u == null) {
    //   return false;
    // } else {
    //   // load user info from firestore
    //   isAnonymous = u.isAnonymous;
    //   await loadUser(u.uid);
    //   return true;
    // }
  }

  static Future signout(context, [bool forceSignout = false]) async {
    try {
      if (!forceSignout) {
        var result = await AppNavigator.confirmMessage(
            context, AppLocale.translate('Are you sure you want to logout?'));
        if (!result) return;
        try {
          int pending = await TecfySyncService.getUnpostedCount();
          if (pending > 0) {
            result = await AppNavigator.confirmMessage(context,
                'You have $pending local items not posted to server!!!!',
                message:
                    AppLocale.translate('Are you sure you want to logout?'));
            if (!result) return;
          }
        } catch (e) {}
      }

      try {
        DashboardController.dashboards = null;
        await ConfigService.resetConfig();
        await ConfigService.setValueString('Entity', null);
        await ConfigService.setValueString('DashboardAllType', null);
        await ConfigService.resetConfig();
      } catch (err) {}
      // await DatabaseService.deleteDatabaseFile();
      await TecfySyncService.reset();
      await DatabaseService.init();
      AppNavigator.navigateToNamed(context, '/login',
          replaceAll: true, animationType: AnimationTypes.opacity);
    } catch (err, stack) {
      print('XXXXXXXXXXXX Logout ');
      print(err);
      print(stack);
      AppNavigator.showMessage(context, 'Error', MessageType.error);
    }
  }

  static lock(context) async {
    try {
      await ConfigService.setValueBool('LoginExpired', true);
      AppNavigator.navigateToNamed(context, '/login',
          replaceAll: true, animationType: AnimationTypes.opacity);
    } catch (err, stack) {
      print('XXXXXXXXXXXX Logout ');
      print(err);
      print(stack);
      AppNavigator.showMessage(context, 'Error', MessageType.error);
    }
  }

  static loginExpired(context) async {
    try {
      await ConfigService.setValueBool('LoginExpired', true);
      AppNavigator.navigateToNamed(context, '/login',
          replaceAll: true, animationType: AnimationTypes.opacity);
    } catch (err, stack) {
      print('XXXXXXXXXXXX Logout ');
      print(err);
      print(stack);
      AppNavigator.showMessage(context, 'Error', MessageType.error);
    }
  }

  static Future<OperationResult> loadUser(String id) async {
    try {
      // var userDataMap =
      //     await Firestore.instance.collection('users').document(id).get();

      // user = User.fromJson(id, userDataMap.data);
      //ConfigService.saveConfig();

      // await prefs.commit();
      return OperationResult(success: true);
    } catch (err) {
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<bool>> isLogin(context) async {
    if (ConfigService.isLogin)
      return OperationResult(success: true, data: true);
    await Future.delayed(Duration(milliseconds: 100));

    return OperationResult(success: true, data: false);
  }
}
